// =================================================================================================
// CopySourceAsHtml
// 
// Copyright  2006 J.T. Leigh & Associates Inc.  All rights reserved.
// 
// Microsoft and Visual Studio are either trademarks or registered trademarks 
// Corporation.
// 
// THIS SOFTWARE IS PROVIDED "AS-IS," WITHOUT WARRANTY OF ANY KIND, AND ANY USE OF THIS SOFTWARE 
// PRODUCT IS AT YOUR OWN RISK.  TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, J.T. LEIGH &
// ASSOCIATES AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES AND CONDITIONS, EITHER EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES AND CONDITIONS OF MERCHANTABILITY AND/OR 
// FITNESS FOR A PARTICULAR PURPOSE, TITLE, AND NON-INFRINGEMENT, WITH REGARD TO THE SOFTWARE. 
// =================================================================================================

using System;

namespace JTLeigh.Tools.CopySourceAsHtml
{

    public sealed class ColorableItemStyle : HtmlStyle
    {

        private string foregroundColor;
        private string backgroundColor;
        private bool bold;



        public ColorableItemStyle(string foregroundColor, string backgroundColor, bool bold)
            : this(foregroundColor, backgroundColor, bold, null)
        {
        }

        public ColorableItemStyle(string foregroundColor, string backgroundColor, bool bold, ColorableItemStyle parentStyle)
        {
            this.foregroundColor = foregroundColor;
            this.backgroundColor = backgroundColor;
            this.bold = bold;
            if ((parentStyle == null) || (!foregroundColor.Equals(parentStyle.ForegroundColor)))
            {
                AppendFormat("color: {0};", foregroundColor);
            }
            if ((parentStyle == null) || (!backgroundColor.Equals(parentStyle.BackgroundColor)))
            {
                AppendFormat("background: {0};", backgroundColor);
            }
            if ((parentStyle == null) && bold)
            {
                Append("font-weight: bold;");
            }
            else if ((parentStyle != null) && (bold != parentStyle.Bold))
            {
                if (bold)
                {
                    Append("font-weight: bold;");
                }
                else
                {
                    Append("font-weight: normal;");
                }
            }
        }

        public string ForegroundColor
        {
            get { return this.foregroundColor; }
        }

        public string BackgroundColor
        {
            get { return this.backgroundColor; }
        }

        public bool Bold
        {
            get { return this.bold; }
        }

    }

}
