// =================================================================================================
// CopySourceAsHtml
// 
// Copyright  2006 J.T. Leigh & Associates Inc.  All rights reserved.
// 
// Microsoft and Visual Studio are either trademarks or registered trademarks 
// Corporation.
// 
// THIS SOFTWARE IS PROVIDED "AS-IS," WITHOUT WARRANTY OF ANY KIND, AND ANY USE OF THIS SOFTWARE 
// PRODUCT IS AT YOUR OWN RISK.  TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, J.T. LEIGH &
// ASSOCIATES AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES AND CONDITIONS, EITHER EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES AND CONDITIONS OF MERCHANTABILITY AND/OR 
// FITNESS FOR A PARTICULAR PURPOSE, TITLE, AND NON-INFRINGEMENT, WITH REGARD TO THE SOFTWARE. 
// =================================================================================================

using System;
using System.Diagnostics;
using System.Globalization;
using System.Windows.Forms;
using JTLeigh.Tools.CopySourceAsHtml.Properties;

namespace JTLeigh.Tools.CopySourceAsHtml
{

    public sealed class CopierPreferencesDialog : Form
    {

        private TabControl tabs;

        private TabPage tabGeneral;
        private CheckBox numberLinesCheck;
        private TextBox numberLinesFromText;
        private CheckBox wrapWordsCheck;
        private CheckBox embedStylesCheck;
        private CheckBox stripLineBreaksCheck;
        private CheckBox removeIndentationCheck;
        private CheckBox overrideTabSizeCheck;
        private TextBox tabSizeText;
        private CheckBox overrideFontListCheck;
        private TextBox fontListText;
        private CheckBox overrideFontSizeCheck;
        private TextBox fontSizeText;

        private TabPage tabFileStyle;
        private Label fileStyleLabel;
        private TextBox fileStyleText;

        private TabPage tabLineStyle;
        private Label lineStyleLabel;
        private TextBox lineStyleText;

        private TabPage tabBlockStyle;
        private Label blockStyleLabel;
        private TextBox blockStyleText;

        private TabPage tabAddIn;
        private CheckBox addCopyContextMenuCheck;
        private CheckBox addCopyNowContextMenuCheck;

        private TabPage tabAbout;
        private Label versionLabel;
        private Label copyrightLabel;
        private TextBox licenseText;
        private LinkLabel creditLabel;

        private Button okButton;
        private Button cancelButton;

        private System.ComponentModel.Container components = null;
        private CheckBox addCopyNowEditMenuCheck;
        private CheckBox addCopyEditMenuCheck;
        private Label copyLabel;
        private CheckBox includeRtfCheck;
        private Label copyNowLabel;

        public CopierPreferencesDialog()
        {

            InitializeComponent();

            creditLabel.Links.Add(46, 5, "mailto:colinc@jtleigh.com");
            creditLabel.Links.Add(54, 3, "http://www.jtleigh.com/people/colin/blog/");
            creditLabel.Links.Add(60, 3, "http://www.jtleigh.com/people/colin/blog/index.xml");

            numberLinesCheck.Checked = Settings.Default.NumberLines;
            numberLinesFromText.Text = Settings.Default.NumberLinesFrom.ToString(NumberFormatInfo.InvariantInfo);
            numberLinesFromText.Enabled = Settings.Default.NumberLines;
            wrapWordsCheck.Checked = Settings.Default.WrapWords;
            embedStylesCheck.Checked = Settings.Default.EmbedStyles;
            includeRtfCheck.Checked = Settings.Default.IncludeRtf;
            stripLineBreaksCheck.Checked = Settings.Default.StripLineBreaks;
            removeIndentationCheck.Checked = Settings.Default.RemoveIndentation;
            overrideTabSizeCheck.Checked = Settings.Default.OverrideTabSize;
            tabSizeText.Text = Settings.Default.TabSize.ToString(NumberFormatInfo.InvariantInfo);
            tabSizeText.Enabled = Settings.Default.OverrideTabSize;
            overrideFontListCheck.Checked = Settings.Default.OverrideFontList;
            fontListText.Text = Tools.GetCleanFontList(Settings.Default.FontList);
            fontListText.Enabled = Settings.Default.OverrideFontList;
            overrideFontSizeCheck.Checked = Settings.Default.OverrideFontSize;
            fontSizeText.Text = Settings.Default.FontSize.ToString(NumberFormatInfo.InvariantInfo);
            fontSizeText.Enabled = Settings.Default.OverrideFontSize;
            fileStyleText.Text = Tools.GetFriendlyStyleList(Settings.Default.FileStyle);
            lineStyleText.Text = Tools.GetFriendlyStyleList(Settings.Default.LineStyle);
            blockStyleText.Text = Tools.GetFriendlyStyleList(Settings.Default.BlockStyle);
            addCopyEditMenuCheck.Checked = Settings.Default.AddCopyEditMenu;
            addCopyNowEditMenuCheck.Checked = Settings.Default.AddCopyNowEditMenu;
            addCopyContextMenuCheck.Checked = Settings.Default.AddCopyContextMenu;
            addCopyNowContextMenuCheck.Checked = Settings.Default.AddCopyNowContextMenu;

        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                if (components != null)
                {
                    components.Dispose();
                }
            }
            base.Dispose(disposing);
        }

        #region Windows Form Designer generated code
        /// <summary>
        /// Required method for Designer support - do not modify
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(CopierPreferencesDialog));
            this.okButton = new System.Windows.Forms.Button();
            this.cancelButton = new System.Windows.Forms.Button();
            this.tabs = new System.Windows.Forms.TabControl();
            this.tabGeneral = new System.Windows.Forms.TabPage();
            this.includeRtfCheck = new System.Windows.Forms.CheckBox();
            this.removeIndentationCheck = new System.Windows.Forms.CheckBox();
            this.tabSizeText = new System.Windows.Forms.TextBox();
            this.overrideTabSizeCheck = new System.Windows.Forms.CheckBox();
            this.fontListText = new System.Windows.Forms.TextBox();
            this.fontSizeText = new System.Windows.Forms.TextBox();
            this.overrideFontSizeCheck = new System.Windows.Forms.CheckBox();
            this.overrideFontListCheck = new System.Windows.Forms.CheckBox();
            this.stripLineBreaksCheck = new System.Windows.Forms.CheckBox();
            this.embedStylesCheck = new System.Windows.Forms.CheckBox();
            this.numberLinesFromText = new System.Windows.Forms.TextBox();
            this.numberLinesCheck = new System.Windows.Forms.CheckBox();
            this.wrapWordsCheck = new System.Windows.Forms.CheckBox();
            this.tabFileStyle = new System.Windows.Forms.TabPage();
            this.fileStyleLabel = new System.Windows.Forms.Label();
            this.fileStyleText = new System.Windows.Forms.TextBox();
            this.tabLineStyle = new System.Windows.Forms.TabPage();
            this.lineStyleLabel = new System.Windows.Forms.Label();
            this.lineStyleText = new System.Windows.Forms.TextBox();
            this.tabBlockStyle = new System.Windows.Forms.TabPage();
            this.blockStyleLabel = new System.Windows.Forms.Label();
            this.blockStyleText = new System.Windows.Forms.TextBox();
            this.tabAddIn = new System.Windows.Forms.TabPage();
            this.copyNowLabel = new System.Windows.Forms.Label();
            this.copyLabel = new System.Windows.Forms.Label();
            this.addCopyNowEditMenuCheck = new System.Windows.Forms.CheckBox();
            this.addCopyEditMenuCheck = new System.Windows.Forms.CheckBox();
            this.addCopyNowContextMenuCheck = new System.Windows.Forms.CheckBox();
            this.addCopyContextMenuCheck = new System.Windows.Forms.CheckBox();
            this.tabAbout = new System.Windows.Forms.TabPage();
            this.creditLabel = new System.Windows.Forms.LinkLabel();
            this.copyrightLabel = new System.Windows.Forms.Label();
            this.versionLabel = new System.Windows.Forms.Label();
            this.licenseText = new System.Windows.Forms.TextBox();
            this.tabs.SuspendLayout();
            this.tabGeneral.SuspendLayout();
            this.tabFileStyle.SuspendLayout();
            this.tabLineStyle.SuspendLayout();
            this.tabBlockStyle.SuspendLayout();
            this.tabAddIn.SuspendLayout();
            this.tabAbout.SuspendLayout();
            this.SuspendLayout();
            // 
            // okButton
            // 
            this.okButton.DialogResult = System.Windows.Forms.DialogResult.OK;
            this.okButton.Location = new System.Drawing.Point(144, 200);
            this.okButton.Name = "okButton";
            this.okButton.Size = new System.Drawing.Size(75, 23);
            this.okButton.TabIndex = 16;
            this.okButton.Text = "OK";
            this.okButton.Click += new System.EventHandler(this.okButton_Click);
            // 
            // cancelButton
            // 
            this.cancelButton.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            this.cancelButton.Location = new System.Drawing.Point(224, 200);
            this.cancelButton.Name = "cancelButton";
            this.cancelButton.Size = new System.Drawing.Size(75, 23);
            this.cancelButton.TabIndex = 17;
            this.cancelButton.Text = "Cancel";
            // 
            // tabs
            // 
            this.tabs.Controls.Add(this.tabGeneral);
            this.tabs.Controls.Add(this.tabFileStyle);
            this.tabs.Controls.Add(this.tabLineStyle);
            this.tabs.Controls.Add(this.tabBlockStyle);
            this.tabs.Controls.Add(this.tabAddIn);
            this.tabs.Controls.Add(this.tabAbout);
            this.tabs.Location = new System.Drawing.Point(8, 8);
            this.tabs.Name = "tabs";
            this.tabs.SelectedIndex = 0;
            this.tabs.Size = new System.Drawing.Size(424, 184);
            this.tabs.TabIndex = 0;
            // 
            // tabGeneral
            // 
            this.tabGeneral.Controls.Add(this.includeRtfCheck);
            this.tabGeneral.Controls.Add(this.removeIndentationCheck);
            this.tabGeneral.Controls.Add(this.tabSizeText);
            this.tabGeneral.Controls.Add(this.overrideTabSizeCheck);
            this.tabGeneral.Controls.Add(this.fontListText);
            this.tabGeneral.Controls.Add(this.fontSizeText);
            this.tabGeneral.Controls.Add(this.overrideFontSizeCheck);
            this.tabGeneral.Controls.Add(this.overrideFontListCheck);
            this.tabGeneral.Controls.Add(this.stripLineBreaksCheck);
            this.tabGeneral.Controls.Add(this.embedStylesCheck);
            this.tabGeneral.Controls.Add(this.numberLinesFromText);
            this.tabGeneral.Controls.Add(this.numberLinesCheck);
            this.tabGeneral.Controls.Add(this.wrapWordsCheck);
            this.tabGeneral.Location = new System.Drawing.Point(4, 22);
            this.tabGeneral.Name = "tabGeneral";
            this.tabGeneral.Size = new System.Drawing.Size(416, 158);
            this.tabGeneral.TabIndex = 0;
            this.tabGeneral.Text = "General";
            // 
            // includeRtfCheck
            // 
            this.includeRtfCheck.BackColor = System.Drawing.SystemColors.Control;
            this.includeRtfCheck.Location = new System.Drawing.Point(212, 56);
            this.includeRtfCheck.Name = "includeRtfCheck";
            this.includeRtfCheck.Size = new System.Drawing.Size(128, 16);
            this.includeRtfCheck.TabIndex = 7;
            this.includeRtfCheck.Text = "Include &RTF";
            this.includeRtfCheck.UseVisualStyleBackColor = false;
            // 
            // removeIndentationCheck
            // 
            this.removeIndentationCheck.BackColor = System.Drawing.SystemColors.Control;
            this.removeIndentationCheck.Location = new System.Drawing.Point(212, 32);
            this.removeIndentationCheck.Name = "removeIndentationCheck";
            this.removeIndentationCheck.Size = new System.Drawing.Size(128, 16);
            this.removeIndentationCheck.TabIndex = 5;
            this.removeIndentationCheck.Text = "Remove &indentation";
            this.removeIndentationCheck.UseVisualStyleBackColor = false;
            // 
            // tabSizeText
            // 
            this.tabSizeText.Location = new System.Drawing.Point(136, 80);
            this.tabSizeText.Name = "tabSizeText";
            this.tabSizeText.Size = new System.Drawing.Size(24, 20);
            this.tabSizeText.TabIndex = 9;
            // 
            // overrideTabSizeCheck
            // 
            this.overrideTabSizeCheck.Location = new System.Drawing.Point(8, 80);
            this.overrideTabSizeCheck.Name = "overrideTabSizeCheck";
            this.overrideTabSizeCheck.Size = new System.Drawing.Size(120, 16);
            this.overrideTabSizeCheck.TabIndex = 8;
            this.overrideTabSizeCheck.Text = "Override &tab size:";
            this.overrideTabSizeCheck.CheckedChanged += new System.EventHandler(this.overrideTabSizeCheck_CheckedChanged);
            // 
            // fontListText
            // 
            this.fontListText.Location = new System.Drawing.Point(136, 104);
            this.fontListText.Name = "fontListText";
            this.fontListText.Size = new System.Drawing.Size(272, 20);
            this.fontListText.TabIndex = 11;
            // 
            // fontSizeText
            // 
            this.fontSizeText.Location = new System.Drawing.Point(136, 128);
            this.fontSizeText.Name = "fontSizeText";
            this.fontSizeText.Size = new System.Drawing.Size(24, 20);
            this.fontSizeText.TabIndex = 0;
            // 
            // overrideFontSizeCheck
            // 
            this.overrideFontSizeCheck.Location = new System.Drawing.Point(8, 128);
            this.overrideFontSizeCheck.Name = "overrideFontSizeCheck";
            this.overrideFontSizeCheck.Size = new System.Drawing.Size(120, 16);
            this.overrideFontSizeCheck.TabIndex = 12;
            this.overrideFontSizeCheck.Text = "Override font &size:";
            this.overrideFontSizeCheck.CheckedChanged += new System.EventHandler(this.overrideFontSizeCheck_CheckedChanged);
            // 
            // overrideFontListCheck
            // 
            this.overrideFontListCheck.Location = new System.Drawing.Point(8, 104);
            this.overrideFontListCheck.Name = "overrideFontListCheck";
            this.overrideFontListCheck.Size = new System.Drawing.Size(120, 16);
            this.overrideFontListCheck.TabIndex = 10;
            this.overrideFontListCheck.Text = "Override &font list:";
            this.overrideFontListCheck.CheckedChanged += new System.EventHandler(this.overrideFontListCheck_CheckedChanged);
            // 
            // stripLineBreaksCheck
            // 
            this.stripLineBreaksCheck.BackColor = System.Drawing.SystemColors.Control;
            this.stripLineBreaksCheck.Location = new System.Drawing.Point(212, 8);
            this.stripLineBreaksCheck.Name = "stripLineBreaksCheck";
            this.stripLineBreaksCheck.Size = new System.Drawing.Size(112, 16);
            this.stripLineBreaksCheck.TabIndex = 3;
            this.stripLineBreaksCheck.Text = "Strip line &breaks";
            this.stripLineBreaksCheck.UseVisualStyleBackColor = false;
            // 
            // embedStylesCheck
            // 
            this.embedStylesCheck.BackColor = System.Drawing.SystemColors.Control;
            this.embedStylesCheck.Location = new System.Drawing.Point(8, 56);
            this.embedStylesCheck.Name = "embedStylesCheck";
            this.embedStylesCheck.Size = new System.Drawing.Size(96, 16);
            this.embedStylesCheck.TabIndex = 6;
            this.embedStylesCheck.Text = "&Embed styles";
            this.embedStylesCheck.UseVisualStyleBackColor = false;
            // 
            // numberLinesFromText
            // 
            this.numberLinesFromText.Location = new System.Drawing.Point(136, 8);
            this.numberLinesFromText.Name = "numberLinesFromText";
            this.numberLinesFromText.Size = new System.Drawing.Size(48, 20);
            this.numberLinesFromText.TabIndex = 2;
            // 
            // numberLinesCheck
            // 
            this.numberLinesCheck.Location = new System.Drawing.Point(8, 8);
            this.numberLinesCheck.Name = "numberLinesCheck";
            this.numberLinesCheck.Size = new System.Drawing.Size(128, 16);
            this.numberLinesCheck.TabIndex = 1;
            this.numberLinesCheck.Text = "&Number lines from:";
            this.numberLinesCheck.CheckedChanged += new System.EventHandler(this.numberLinesCheck_CheckedChanged);
            // 
            // wrapWordsCheck
            // 
            this.wrapWordsCheck.BackColor = System.Drawing.SystemColors.Control;
            this.wrapWordsCheck.Location = new System.Drawing.Point(8, 32);
            this.wrapWordsCheck.Name = "wrapWordsCheck";
            this.wrapWordsCheck.Size = new System.Drawing.Size(88, 16);
            this.wrapWordsCheck.TabIndex = 4;
            this.wrapWordsCheck.Text = "&Wrap words";
            this.wrapWordsCheck.UseVisualStyleBackColor = false;
            // 
            // tabFileStyle
            // 
            this.tabFileStyle.Controls.Add(this.fileStyleLabel);
            this.tabFileStyle.Controls.Add(this.fileStyleText);
            this.tabFileStyle.Location = new System.Drawing.Point(4, 22);
            this.tabFileStyle.Name = "tabFileStyle";
            this.tabFileStyle.Size = new System.Drawing.Size(416, 158);
            this.tabFileStyle.TabIndex = 1;
            this.tabFileStyle.Text = "File Style";
            // 
            // fileStyleLabel
            // 
            this.fileStyleLabel.Location = new System.Drawing.Point(8, 8);
            this.fileStyleLabel.Name = "fileStyleLabel";
            this.fileStyleLabel.Size = new System.Drawing.Size(392, 16);
            this.fileStyleLabel.TabIndex = 1;
            this.fileStyleLabel.Text = "Additional CSS rules for the file\'s <div> tag:";
            // 
            // fileStyleText
            // 
            this.fileStyleText.AcceptsReturn = true;
            this.fileStyleText.Location = new System.Drawing.Point(8, 24);
            this.fileStyleText.Multiline = true;
            this.fileStyleText.Name = "fileStyleText";
            this.fileStyleText.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.fileStyleText.Size = new System.Drawing.Size(400, 128);
            this.fileStyleText.TabIndex = 13;
            // 
            // tabLineStyle
            // 
            this.tabLineStyle.Controls.Add(this.lineStyleLabel);
            this.tabLineStyle.Controls.Add(this.lineStyleText);
            this.tabLineStyle.Location = new System.Drawing.Point(4, 22);
            this.tabLineStyle.Name = "tabLineStyle";
            this.tabLineStyle.Size = new System.Drawing.Size(416, 158);
            this.tabLineStyle.TabIndex = 2;
            this.tabLineStyle.Text = "Line Style";
            // 
            // lineStyleLabel
            // 
            this.lineStyleLabel.Location = new System.Drawing.Point(8, 8);
            this.lineStyleLabel.Name = "lineStyleLabel";
            this.lineStyleLabel.Size = new System.Drawing.Size(392, 16);
            this.lineStyleLabel.TabIndex = 2;
            this.lineStyleLabel.Text = "Additional CSS rules for each line\'s <p> or <pre> tag:";
            // 
            // lineStyleText
            // 
            this.lineStyleText.AcceptsReturn = true;
            this.lineStyleText.Location = new System.Drawing.Point(8, 24);
            this.lineStyleText.Multiline = true;
            this.lineStyleText.Name = "lineStyleText";
            this.lineStyleText.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.lineStyleText.Size = new System.Drawing.Size(400, 128);
            this.lineStyleText.TabIndex = 14;
            // 
            // tabBlockStyle
            // 
            this.tabBlockStyle.Controls.Add(this.blockStyleLabel);
            this.tabBlockStyle.Controls.Add(this.blockStyleText);
            this.tabBlockStyle.Location = new System.Drawing.Point(4, 22);
            this.tabBlockStyle.Name = "tabBlockStyle";
            this.tabBlockStyle.Size = new System.Drawing.Size(416, 158);
            this.tabBlockStyle.TabIndex = 3;
            this.tabBlockStyle.Text = "Block Style";
            // 
            // blockStyleLabel
            // 
            this.blockStyleLabel.Location = new System.Drawing.Point(8, 8);
            this.blockStyleLabel.Name = "blockStyleLabel";
            this.blockStyleLabel.Size = new System.Drawing.Size(392, 16);
            this.blockStyleLabel.TabIndex = 3;
            this.blockStyleLabel.Text = "Additional CSS rules for each block\'s <span> tag:";
            // 
            // blockStyleText
            // 
            this.blockStyleText.AcceptsReturn = true;
            this.blockStyleText.Location = new System.Drawing.Point(8, 24);
            this.blockStyleText.Multiline = true;
            this.blockStyleText.Name = "blockStyleText";
            this.blockStyleText.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.blockStyleText.Size = new System.Drawing.Size(400, 128);
            this.blockStyleText.TabIndex = 15;
            // 
            // tabAddIn
            // 
            this.tabAddIn.Controls.Add(this.copyNowLabel);
            this.tabAddIn.Controls.Add(this.copyLabel);
            this.tabAddIn.Controls.Add(this.addCopyNowEditMenuCheck);
            this.tabAddIn.Controls.Add(this.addCopyEditMenuCheck);
            this.tabAddIn.Controls.Add(this.addCopyNowContextMenuCheck);
            this.tabAddIn.Controls.Add(this.addCopyContextMenuCheck);
            this.tabAddIn.Location = new System.Drawing.Point(4, 22);
            this.tabAddIn.Name = "tabAddIn";
            this.tabAddIn.Size = new System.Drawing.Size(416, 158);
            this.tabAddIn.TabIndex = 5;
            this.tabAddIn.Text = "Add-In";
            // 
            // copyNowLabel
            // 
            this.copyNowLabel.Location = new System.Drawing.Point(8, 80);
            this.copyNowLabel.Name = "copyNowLabel";
            this.copyNowLabel.Size = new System.Drawing.Size(400, 16);
            this.copyNowLabel.TabIndex = 6;
            this.copyNowLabel.Text = "Copying without prompting:";
            // 
            // copyLabel
            // 
            this.copyLabel.Location = new System.Drawing.Point(8, 8);
            this.copyLabel.Name = "copyLabel";
            this.copyLabel.Size = new System.Drawing.Size(400, 16);
            this.copyLabel.TabIndex = 5;
            this.copyLabel.Text = "Copying with prompting:";
            // 
            // addCopyNowEditMenuCheck
            // 
            this.addCopyNowEditMenuCheck.BackColor = System.Drawing.SystemColors.Control;
            this.addCopyNowEditMenuCheck.Location = new System.Drawing.Point(8, 104);
            this.addCopyNowEditMenuCheck.Name = "addCopyNowEditMenuCheck";
            this.addCopyNowEditMenuCheck.Size = new System.Drawing.Size(400, 16);
            this.addCopyNowEditMenuCheck.TabIndex = 3;
            this.addCopyNowEditMenuCheck.Text = "Add \"Copy As HTML\" to Edit menu";
            this.addCopyNowEditMenuCheck.UseVisualStyleBackColor = false;
            // 
            // addCopyEditMenuCheck
            // 
            this.addCopyEditMenuCheck.BackColor = System.Drawing.SystemColors.Control;
            this.addCopyEditMenuCheck.Location = new System.Drawing.Point(8, 32);
            this.addCopyEditMenuCheck.Name = "addCopyEditMenuCheck";
            this.addCopyEditMenuCheck.Size = new System.Drawing.Size(400, 16);
            this.addCopyEditMenuCheck.TabIndex = 1;
            this.addCopyEditMenuCheck.Text = "Add \"Copy As HTML...\" to Edit menu";
            this.addCopyEditMenuCheck.UseVisualStyleBackColor = false;
            // 
            // addCopyNowContextMenuCheck
            // 
            this.addCopyNowContextMenuCheck.BackColor = System.Drawing.SystemColors.Control;
            this.addCopyNowContextMenuCheck.Location = new System.Drawing.Point(8, 128);
            this.addCopyNowContextMenuCheck.Name = "addCopyNowContextMenuCheck";
            this.addCopyNowContextMenuCheck.Size = new System.Drawing.Size(400, 16);
            this.addCopyNowContextMenuCheck.TabIndex = 4;
            this.addCopyNowContextMenuCheck.Text = "Add \"Copy As HTML\" to context menus";
            this.addCopyNowContextMenuCheck.UseVisualStyleBackColor = false;
            // 
            // addCopyContextMenuCheck
            // 
            this.addCopyContextMenuCheck.BackColor = System.Drawing.SystemColors.Control;
            this.addCopyContextMenuCheck.Location = new System.Drawing.Point(8, 56);
            this.addCopyContextMenuCheck.Name = "addCopyContextMenuCheck";
            this.addCopyContextMenuCheck.Size = new System.Drawing.Size(400, 16);
            this.addCopyContextMenuCheck.TabIndex = 2;
            this.addCopyContextMenuCheck.Text = "Add \"Copy As HTML...\" to context menus";
            this.addCopyContextMenuCheck.UseVisualStyleBackColor = false;
            // 
            // tabAbout
            // 
            this.tabAbout.Controls.Add(this.creditLabel);
            this.tabAbout.Controls.Add(this.copyrightLabel);
            this.tabAbout.Controls.Add(this.versionLabel);
            this.tabAbout.Controls.Add(this.licenseText);
            this.tabAbout.Location = new System.Drawing.Point(4, 22);
            this.tabAbout.Name = "tabAbout";
            this.tabAbout.Size = new System.Drawing.Size(416, 158);
            this.tabAbout.TabIndex = 4;
            this.tabAbout.Text = "About";
            // 
            // creditLabel
            // 
            this.creditLabel.Location = new System.Drawing.Point(8, 136);
            this.creditLabel.Name = "creditLabel";
            this.creditLabel.Size = new System.Drawing.Size(334, 16);
            this.creditLabel.TabIndex = 2;
            this.creditLabel.TabStop = true;
            this.creditLabel.Text = "CopySourceAsHtml was written by Colin Coller (email) (web) (rss)";
            this.creditLabel.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(this.creditLabel_LinkClicked);
            // 
            // copyrightLabel
            // 
            this.copyrightLabel.Location = new System.Drawing.Point(8, 32);
            this.copyrightLabel.Name = "copyrightLabel";
            this.copyrightLabel.Size = new System.Drawing.Size(400, 16);
            this.copyrightLabel.TabIndex = 8;
            this.copyrightLabel.Text = "Copyright  2006 J.T. Leigh && Associates Inc. All rights reserved.";
            // 
            // versionLabel
            // 
            this.versionLabel.Location = new System.Drawing.Point(8, 8);
            this.versionLabel.Name = "versionLabel";
            this.versionLabel.Size = new System.Drawing.Size(400, 16);
            this.versionLabel.TabIndex = 6;
            this.versionLabel.Text = "CopySourceAsHtml version 2.0.0";
            // 
            // licenseText
            // 
            this.licenseText.Location = new System.Drawing.Point(8, 56);
            this.licenseText.Multiline = true;
            this.licenseText.Name = "licenseText";
            this.licenseText.ReadOnly = true;
            this.licenseText.ScrollBars = System.Windows.Forms.ScrollBars.Vertical;
            this.licenseText.Size = new System.Drawing.Size(400, 72);
            this.licenseText.TabIndex = 1;
            this.licenseText.Text = resources.GetString("licenseText.Text");
            // 
            // CopierPreferencesDialog
            // 
            this.AcceptButton = this.okButton;
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.CancelButton = this.cancelButton;
            this.ClientSize = new System.Drawing.Size(442, 231);
            this.ControlBox = false;
            this.Controls.Add(this.tabs);
            this.Controls.Add(this.cancelButton);
            this.Controls.Add(this.okButton);
            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
            this.MaximizeBox = false;
            this.MinimizeBox = false;
            this.Name = "CopierPreferencesDialog";
            this.ShowInTaskbar = false;
            this.SizeGripStyle = System.Windows.Forms.SizeGripStyle.Hide;
            this.StartPosition = System.Windows.Forms.FormStartPosition.CenterScreen;
            this.Text = "Copy As HTML";
            this.tabs.ResumeLayout(false);
            this.tabGeneral.ResumeLayout(false);
            this.tabGeneral.PerformLayout();
            this.tabFileStyle.ResumeLayout(false);
            this.tabFileStyle.PerformLayout();
            this.tabLineStyle.ResumeLayout(false);
            this.tabLineStyle.PerformLayout();
            this.tabBlockStyle.ResumeLayout(false);
            this.tabBlockStyle.PerformLayout();
            this.tabAddIn.ResumeLayout(false);
            this.tabAbout.ResumeLayout(false);
            this.tabAbout.PerformLayout();
            this.ResumeLayout(false);

        }
        #endregion

        private void okButton_Click(object sender, EventArgs args)
        {

            int numberLinesFrom = 0;
            int tabSize = -1;
            string fontList = null;
            int fontSize = 0;
            string fileStyle = null;
            string lineStyle = null;
            string blockStyle = null;

            if (numberLinesCheck.Checked)
            {
                try
                {
                    numberLinesFrom = Int32.Parse(numberLinesFromText.Text);
                }
                catch
                {
                    numberLinesFrom = 0;
                }
                if (numberLinesFrom < 1)
                {
                    MessageBox.Show(Resources.InvalidLineNumberMessage, Resources.InvalidLineNumberCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                    numberLinesFromText.Focus();
                    return;
                }
            }
            if (overrideTabSizeCheck.Checked)
            {
                try
                {
                    tabSize = Int32.Parse(tabSizeText.Text);
                }
                catch
                {
                    tabSize = -1;
                }
                if (tabSize < 0)
                {
                    MessageBox.Show(Resources.InvalidTabSizeMessage, Resources.InvalidTabSizeCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                    tabSizeText.Focus();
                    return;
                }
            }
            if (overrideFontListCheck.Checked)
            {
                fontList = Tools.GetCleanFontList(fontListText.Text);
                if (fontList == null)
                {
                    MessageBox.Show(Resources.InvalidFontListMessage, Resources.InvalidFontListCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                    fontListText.Focus();
                    return;
                }
            }
            if (overrideFontSizeCheck.Checked)
            {
                try
                {
                    fontSize = Int32.Parse(fontSizeText.Text);
                }
                catch
                {
                    fontSize = 0;
                }
                if (fontSize < 1)
                {
                    MessageBox.Show(Resources.InvalidFontSizeMessage, Resources.InvalidFontSizeCaption, MessageBoxButtons.OK, MessageBoxIcon.Error);
                    fontSizeText.Focus();
                    return;
                }
            }
            fileStyle = Tools.GetCompactStyleList(fileStyleText.Text);
            lineStyle = Tools.GetCompactStyleList(lineStyleText.Text);
            blockStyle = Tools.GetCompactStyleList(blockStyleText.Text);

            // ...

            Settings.Default.NumberLines = numberLinesCheck.Checked;
            if (numberLinesCheck.Checked)
            {
                Settings.Default.NumberLinesFrom = numberLinesFrom;
            }
            Settings.Default.WrapWords = wrapWordsCheck.Checked;
            Settings.Default.EmbedStyles = embedStylesCheck.Checked;
            Settings.Default.IncludeRtf = includeRtfCheck.Checked;
            Settings.Default.StripLineBreaks = stripLineBreaksCheck.Checked;
            Settings.Default.RemoveIndentation = removeIndentationCheck.Checked;
            Settings.Default.OverrideTabSize = overrideTabSizeCheck.Checked;
            if (overrideTabSizeCheck.Checked)
            {
                Settings.Default.TabSize = tabSize;
            }
            Settings.Default.OverrideFontList = overrideFontListCheck.Checked;
            if (overrideFontListCheck.Checked)
            {
                Settings.Default.FontList = fontList;
            }
            Settings.Default.OverrideFontSize = overrideFontSizeCheck.Checked;
            if (overrideFontSizeCheck.Checked)
            {
                Settings.Default.FontSize = fontSize;
            }
            Settings.Default.FileStyle = fileStyle;
            Settings.Default.LineStyle = lineStyle;
            Settings.Default.BlockStyle = blockStyle;
            Settings.Default.AddCopyEditMenu = addCopyEditMenuCheck.Checked;
            Settings.Default.AddCopyNowEditMenu = addCopyNowEditMenuCheck.Checked;
            Settings.Default.AddCopyContextMenu = addCopyContextMenuCheck.Checked;
            Settings.Default.AddCopyNowContextMenu = addCopyNowContextMenuCheck.Checked;

            Settings.Default.Save();

            DialogResult = DialogResult.OK;
            Close();

        }

        private void numberLinesCheck_CheckedChanged(object sender, EventArgs args)
        {
            numberLinesFromText.Enabled = numberLinesCheck.Checked;
        }

        private void overrideTabSizeCheck_CheckedChanged(object sender, EventArgs args)
        {
            tabSizeText.Enabled = overrideTabSizeCheck.Checked;
        }

        private void overrideFontListCheck_CheckedChanged(object sender, EventArgs args)
        {
            fontListText.Enabled = overrideFontListCheck.Checked;
        }

        private void overrideFontSizeCheck_CheckedChanged(object sender, EventArgs args)
        {
            fontSizeText.Enabled = overrideFontSizeCheck.Checked;
        }

        private void creditLabel_LinkClicked(object sender, LinkLabelLinkClickedEventArgs args)
        {
            Process.Start((string)args.Link.LinkData);
        }

    }
}
