// =================================================================================================
// CopySourceAsHtml
// 
// Copyright  2006 J.T. Leigh & Associates Inc.  All rights reserved.
// 
// Microsoft and Visual Studio are either trademarks or registered trademarks 
// Corporation.
// 
// THIS SOFTWARE IS PROVIDED "AS-IS," WITHOUT WARRANTY OF ANY KIND, AND ANY USE OF THIS SOFTWARE 
// PRODUCT IS AT YOUR OWN RISK.  TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, J.T. LEIGH &
// ASSOCIATES AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES AND CONDITIONS, EITHER EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES AND CONDITIONS OF MERCHANTABILITY AND/OR 
// FITNESS FOR A PARTICULAR PURPOSE, TITLE, AND NON-INFRINGEMENT, WITH REGARD TO THE SOFTWARE. 
// =================================================================================================

using System.Text;
using System.Web;

namespace JTLeigh.Tools.CopySourceAsHtml
{

    internal sealed class HtmlBlock
    {

        private bool wrapWords;
        private int tabSize;
        private int foregroundColor;
        private int backgroundColor;
        private bool bold;
        private StringBuilder content;
        private bool hasContent;
        private int leadingSpaces;
        private int trailingSpaces;

        public HtmlBlock(bool wrapWords, int tabSize)
            : this(wrapWords, tabSize, 0, 0, false)
        {
        }

        public HtmlBlock(bool wrapWords, int tabSize, HtmlBlock parentBlock)
            : this(wrapWords, tabSize, parentBlock.ForegroundColor, parentBlock.BackgroundColor, parentBlock.Bold)
        {
        }

        private HtmlBlock(bool wrapWords, int tabSize, int foregroundColor, int backgroundColor, bool bold)
        {
            this.wrapWords = wrapWords;
            this.tabSize = tabSize;
            this.foregroundColor = foregroundColor;
            this.backgroundColor = backgroundColor;
            this.bold = bold;
            this.content = new StringBuilder();
            this.hasContent = false;
            this.leadingSpaces = 0;
            this.trailingSpaces = 0;
        }

        public void AppendUnencoded(string value)
        {
            AppendTrailingSpaces();
            this.content.Append(value);
            this.hasContent = true;
        }

        public void AppendEncoded(char value)
        {
            if (value == ' ')
            {
                AppendUnencoded(value);
            }
            else
            {
                AppendUnencoded(Tools.HtmlEncode(value));
            }
        }

        public void AppendUnencoded(char value)
        {
            if (value == ' ')
            {
                if (!this.hasContent)
                {
                    this.leadingSpaces++;
                }
                else
                {
                    this.trailingSpaces++;
                }
            }
            else
            {
                AppendTrailingSpaces();
                this.content.Append(value);
                this.hasContent = true;
            }
        }

        public string GetHtml(bool allowLeadingSpace, int undentSpaces)
        {
            return Tools.GetWhitespace(allowLeadingSpace, this.wrapWords, (this.leadingSpaces - undentSpaces), this.tabSize) + this.content.ToString() + Tools.GetWhitespace(true, this.wrapWords, this.trailingSpaces, this.tabSize);
        }

        private void AppendTrailingSpaces()
        {
            this.content.Append(Tools.GetWhitespace(true, this.wrapWords, this.trailingSpaces, this.tabSize));
            this.trailingSpaces = 0;
        }

        public int ForegroundColor
        {
            get { return this.foregroundColor; }
            set { this.foregroundColor = value; }
        }

        public int BackgroundColor
        {
            get { return this.backgroundColor; }
            set { this.backgroundColor = value; }
        }

        public bool Bold
        {
            get { return this.bold; }
            set { this.bold = value; }
        }

        public bool HasContent
        {
            get { return this.hasContent; }
        }

        public int LeadingSpaces
        {
            get { return this.leadingSpaces; }
        }

    }

}
