// =================================================================================================
// CopySourceAsHtml
// 
// Copyright  2006 J.T. Leigh & Associates Inc.  All rights reserved.
// 
// Microsoft and Visual Studio are either trademarks or registered trademarks 
// Corporation.
// 
// THIS SOFTWARE IS PROVIDED "AS-IS," WITHOUT WARRANTY OF ANY KIND, AND ANY USE OF THIS SOFTWARE 
// PRODUCT IS AT YOUR OWN RISK.  TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, J.T. LEIGH &
// ASSOCIATES AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES AND CONDITIONS, EITHER EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES AND CONDITIONS OF MERCHANTABILITY AND/OR 
// FITNESS FOR A PARTICULAR PURPOSE, TITLE, AND NON-INFRINGEMENT, WITH REGARD TO THE SOFTWARE. 
// =================================================================================================

using System.Collections;
using System.Collections.Generic;

namespace JTLeigh.Tools.CopySourceAsHtml
{

    internal sealed class HtmlFile
    {

        private bool wrapWords;
        private int tabSize;
        private List<HtmlLine> lines;
        private HtmlLine currentLine;
        private Stack<HtmlBlock> blocks;
        private HtmlBlock currentBlock;

        public HtmlFile(bool wrapWords, int tabSize)
        {
            this.wrapWords = wrapWords;
            this.tabSize = tabSize;
            this.lines = new List<HtmlLine>();
            this.currentLine = new HtmlLine();
            this.lines.Add(this.currentLine);
            this.blocks = new Stack<HtmlBlock>();
            this.currentBlock = new HtmlBlock(wrapWords, tabSize);
            this.currentLine.AddBlock(this.currentBlock);
        }

        public void PushBlock()
        {
            this.blocks.Push(this.currentBlock);
            StartNewBlock(this.currentBlock);
        }

        public void PopBlock()
        {

            HtmlBlock parentBlock;

            parentBlock = this.blocks.Pop();
            StartNewBlock(parentBlock);

        }

        public void AppendUnencoded(char value)
        {
            this.currentBlock.AppendUnencoded(value);
        }

        public void AppendEncoded(char value)
        {
            this.currentBlock.AppendEncoded(value);
        }

        public void StartNewLine()
        {
            this.currentLine = new HtmlLine();
            this.lines.Add(this.currentLine);
            StartNewBlock(this.currentBlock);
        }

        private void StartNewBlock(HtmlBlock parentBlock)
        {
            this.currentBlock = new HtmlBlock(this.wrapWords, this.tabSize, parentBlock);
            this.currentLine.AddBlock(this.currentBlock);
        }

        private void CommitBlock()
        {
            if ((this.currentBlock.HasContent) || (this.currentBlock.LeadingSpaces > 0))
            {
                StartNewBlock(this.currentBlock);
            }
        }

        public List<HtmlLine> Lines
        {
            get { return this.lines; }
        }

        public int ForegroundColor
        {
            set
            {
                if (this.currentBlock.ForegroundColor != value)
                {
                    CommitBlock();
                    this.currentBlock.ForegroundColor = value;
                }
            }
        }

        public int BackgroundColor
        {
            set
            {
                if (this.currentBlock.BackgroundColor != value)
                {
                    CommitBlock();
                    this.currentBlock.BackgroundColor = value;
                }
            }
        }

        public bool Bold
        {
            set
            {
                if (this.currentBlock.Bold != value)
                {
                    CommitBlock();
                    this.currentBlock.Bold = value;
                }
            }
        }

    }

}
