// =================================================================================================
// CopySourceAsHtml
// 
// Copyright  2006 J.T. Leigh & Associates Inc.  All rights reserved.
// 
// Microsoft and Visual Studio are either trademarks or registered trademarks 
// Corporation.
// 
// THIS SOFTWARE IS PROVIDED "AS-IS," WITHOUT WARRANTY OF ANY KIND, AND ANY USE OF THIS SOFTWARE 
// PRODUCT IS AT YOUR OWN RISK.  TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, J.T. LEIGH &
// ASSOCIATES AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES AND CONDITIONS, EITHER EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES AND CONDITIONS OF MERCHANTABILITY AND/OR 
// FITNESS FOR A PARTICULAR PURPOSE, TITLE, AND NON-INFRINGEMENT, WITH REGARD TO THE SOFTWARE. 
// =================================================================================================

using System;
using System.Collections.Generic;
using System.Text;

namespace JTLeigh.Tools.CopySourceAsHtml
{

    public class HtmlStyleSheet
    {

        private SortedList<string, HtmlStyle> addedStyles;
        private SortedList<string, HtmlStyle> reusedStyles;

        public HtmlStyleSheet()
        {
            this.addedStyles = new SortedList<string, HtmlStyle>();
            this.reusedStyles = new SortedList<string, HtmlStyle>();
        }

        public string AddStyle(string name, HtmlStyle style)
        {
            this.addedStyles[name] = style;
            return name;
        }

        public string ReuseStyle(string prefix, HtmlStyle style)
        {

            int id;
            string name;

            id = 1;
            foreach (string key in this.reusedStyles.Keys)
            {
                if (this.reusedStyles[key].Equals(style))
                {
                    return key;
                }
                id++;
            }
            name = String.Format("{0}{1}", prefix, id);
            this.reusedStyles[name] = style;
            return name;

        }

        public string GetHtml(bool stripLineBreaks)
        {

            StringBuilder content;

            content = new StringBuilder();
            content.Append("<style type=\"text/css\">");
            if (!stripLineBreaks)
            {
                content.Append("\n");
            }
            foreach (string key in this.addedStyles.Keys)
            {
                content.AppendFormat(".{0} {{ {1} }}", key, this.addedStyles[key]);
                if (!stripLineBreaks)
                {
                    content.Append("\n");
                }
            }
            foreach (string key in this.reusedStyles.Keys)
            {
                content.AppendFormat(".{0} {{ {1} }}", key, this.reusedStyles[key]);
                if (!stripLineBreaks)
                {
                    content.Append("\n");
                }
            }
            content.Append("</style>");
            if (!stripLineBreaks)
            {
                content.Append("\n");
            }
            return content.ToString();

        }

    }

}
