// =================================================================================================
// CopySourceAsHtml
// 
// Copyright  2006 J.T. Leigh & Associates Inc.  All rights reserved.
// 
// Microsoft and Visual Studio are either trademarks or registered trademarks 
// Corporation.
// 
// THIS SOFTWARE IS PROVIDED "AS-IS," WITHOUT WARRANTY OF ANY KIND, AND ANY USE OF THIS SOFTWARE 
// PRODUCT IS AT YOUR OWN RISK.  TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, J.T. LEIGH &
// ASSOCIATES AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES AND CONDITIONS, EITHER EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES AND CONDITIONS OF MERCHANTABILITY AND/OR 
// FITNESS FOR A PARTICULAR PURPOSE, TITLE, AND NON-INFRINGEMENT, WITH REGARD TO THE SOFTWARE. 
// =================================================================================================

using System;
using System.Text;
using System.Runtime.InteropServices;

namespace JTLeigh.Tools.CopySourceAsHtml
{
    [ComVisible(true)]
    public abstract class RtfParser
    {

        protected void ParseRtf(string rtf)
        {

            int first;
            int last;
            int index;
            int mark;
            string controlWord;
            bool hasParameter;
            long parameter;

            first = 1;
            last = rtf.Length - 1;
            for (index = first; index < last; index++)
            {

                switch (rtf[index])
                {
                    case '{':
                        index += ParseOpeningBrace(rtf, index + 1);
                        break;
                    case '}':
                        index += ParseClosingBrace(rtf, index + 1);
                        break;
                    case '\\':
                        index++;
                        if (char.IsLetter(rtf[index]))
                        {
                            mark = index;
                            while ((index < last) && (char.IsLetter(rtf[index])))
                            {
                                index++;
                            }
                            controlWord = rtf.Substring(mark, index - mark);
                            if ((index < last) && ((char.IsDigit(rtf[index])) || (rtf[index] == '-')))
                            {
                                mark = index;
                                while ((index < last) && ((char.IsDigit(rtf[index])) || (rtf[index] == '-')))
                                {
                                    index++;
                                }
                                hasParameter = true;
                                parameter = Int64.Parse(rtf.Substring(mark, index - mark));
                            }
                            else
                            {
                                hasParameter = false;
                                parameter = 0;
                            }
                            if (rtf[index] != ' ')
                            {
                                index--;
                            }
                            index += ParseControlWord(rtf, index + 1, controlWord, hasParameter, parameter);
                        }
                        else
                        {
                            index += ParseControlSymbol(rtf, index + 1, rtf[index]);
                        }
                        break;
                    case '\r':
                    case '\n':
                        break;
                    default:
                        index += ParseLiteralText(rtf, index + 1, rtf[index]);
                        break;
                }
            }
        }

        protected abstract int ParseControlWord(string rtf, int next, string controlWord, bool hasParameter, long parameter);

        protected abstract int ParseControlSymbol(string rtf, int next, char controlSymbol);

        protected abstract int ParseOpeningBrace(string rtf, int next);

        protected abstract int ParseClosingBrace(string rtf, int next);

        protected abstract int ParseLiteralText(string rtf, int next, char literalText);

    }

}
