// =================================================================================================
// CopySourceAsHtml
// 
// Copyright  2006 J.T. Leigh & Associates Inc.  All rights reserved.
// 
// Microsoft and Visual Studio are either trademarks or registered trademarks 
// Corporation.
// 
// THIS SOFTWARE IS PROVIDED "AS-IS," WITHOUT WARRANTY OF ANY KIND, AND ANY USE OF THIS SOFTWARE 
// PRODUCT IS AT YOUR OWN RISK.  TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, J.T. LEIGH &
// ASSOCIATES AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES AND CONDITIONS, EITHER EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE IMPLIED WARRANTIES AND CONDITIONS OF MERCHANTABILITY AND/OR 
// FITNESS FOR A PARTICULAR PURPOSE, TITLE, AND NON-INFRINGEMENT, WITH REGARD TO THE SOFTWARE. 
// =================================================================================================

using System;
using System.Globalization;
using System.Runtime.InteropServices;
using System.Text;
using System.Text.RegularExpressions;

namespace JTLeigh.Tools.CopySourceAsHtml
{

    internal static class Tools
    {

        [DllImport("olepro32.dll")]
        private static extern uint OleTranslateColor(uint oleColor, uint palette, ref uint refColor);

        public static HtmlColor ConvertColor(uint oleColor)
        {

            uint refColor = 0;
            int r;
            int g;
            int b;

            if (OleTranslateColor(oleColor, 0, ref refColor) != 0)
            {
                throw new Exception("OleTranslateColor failed.");
            }
            r = (int)(refColor & 0xFF);
            g = (int)((refColor >> 8) & 0xFF);
            b = (int)((refColor >> 16) & 0xFF);
            return new HtmlColor(r, g, b);

        }

        public static string GetWhitespace(bool allowLeadingSpace, bool wrapWords, int spaces, int tabSize)
        {

            StringBuilder whitespace;
            int space;

            if (spaces == 0)
            {
                return "";
            }
            if ((spaces == 1) && (!allowLeadingSpace))
            {
                return "&nbsp;";
            }
            whitespace = new StringBuilder(spaces);
            for (space = 1; space < spaces; space++)
            {
                if ((space % tabSize) == 0)
                {
                    whitespace.Append(' ');
                }
                else
                {
                    whitespace.Append("&nbsp;");
                }
            }
            whitespace.Append(' ');
            return whitespace.ToString();

        }

        public static string HtmlEncode(string value)
        {

            StringBuilder encoded;

            encoded = new StringBuilder();
            foreach (char c in value)
            {
                encoded.Append(HtmlEncode(c));
            }
            return encoded.ToString();

        }

        public static string HtmlEncode(char value)
        {
            switch (value)
            {
                case '&':
                    return "&amp;";
                case '<':
                    return "&lt;";
                case '>':
                    return "&gt;";
                default:
                    if ((value >= ' ') && (value <= 0x007e))
                    {
                        return value.ToString();
                    }
                    else
                    {
                        if (!char.IsControl(value))
                        {
                            return "&#" + ((int)value).ToString(NumberFormatInfo.InvariantInfo) + ";";
                        }
                        else
                        {
                            return "?";
                        }
                    }
            }
        }

        public static string GetCleanFontList(string dirtyFontList)
        {

            string[] dirtyFonts;
            StringBuilder cleanFontList;
            string cleanFont;

            if (dirtyFontList == null)
            {
                return null;
            }
            dirtyFonts = dirtyFontList.Split(',');
            cleanFontList = new StringBuilder(dirtyFontList.Length);
            foreach (string dirtyFont in dirtyFonts)
            {
                cleanFont = dirtyFont.Trim();
                if (cleanFont.Length > 0)
                {
                    if (cleanFontList.Length > 0)
                    {
                        cleanFontList.Append(", ");
                    }
                    cleanFontList.Append(cleanFont);
                }
            }
            return cleanFontList.ToString();

        }

        public static string GetCompactStyleList(string friendlyStyleList)
        {

            string[] friendlyStyles;
            StringBuilder compactStyleList;
            string compactStyle;

            if (friendlyStyleList == null)
            {
                return null;
            }
            friendlyStyleList = friendlyStyleList.Replace('\r', ' ');
            friendlyStyleList = friendlyStyleList.Replace('\n', ' ');
            friendlyStyles = friendlyStyleList.Split(';');
            compactStyleList = new StringBuilder(friendlyStyleList.Length);
            foreach (string friendlyStyle in friendlyStyles)
            {
                compactStyle = friendlyStyle.Trim();
                if (compactStyle.Length > 0)
                {
                    if (compactStyleList.Length > 0)
                    {
                        compactStyleList.Append(' ');
                    }
                    compactStyleList.Append(compactStyle);
                    compactStyleList.Append(';');
                }
            }
            return compactStyleList.ToString();

        }

        public static string GetFriendlyStyleList(string compactStyleList)
        {

            string[] compactStyles;
            StringBuilder friendlyStyleList;
            string friendlyStyle;

            if (compactStyleList == null)
            {
                return null;
            }
            compactStyleList = compactStyleList.Replace('\r', ' ');
            compactStyleList = compactStyleList.Replace('\n', ' ');
            compactStyles = compactStyleList.Split(';');
            friendlyStyleList = new StringBuilder(compactStyleList.Length);
            foreach (string compactStyle in compactStyles)
            {
                friendlyStyle = compactStyle.Trim();
                if (friendlyStyle.Length > 0)
                {
                    friendlyStyleList.Append(friendlyStyle);
                    friendlyStyleList.Append(";\r\n");
                }
            }
            return friendlyStyleList.ToString();

        }

    }

}
